# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/admin/cluster_assignment.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='flyteidl/admin/cluster_assignment.proto',
  package='flyteidl.admin',
  syntax='proto3',
  serialized_options=_b('Z5github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/admin'),
  serialized_pb=_b('\n\'flyteidl/admin/cluster_assignment.proto\x12\x0e\x66lyteidl.admin\":\n\x11\x43lusterAssignment\x12\x19\n\x11\x63luster_pool_name\x18\x03 \x01(\tJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03\x42\x37Z5github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/adminb\x06proto3')
)




_CLUSTERASSIGNMENT = _descriptor.Descriptor(
  name='ClusterAssignment',
  full_name='flyteidl.admin.ClusterAssignment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_pool_name', full_name='flyteidl.admin.ClusterAssignment.cluster_pool_name', index=0,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=59,
  serialized_end=117,
)

DESCRIPTOR.message_types_by_name['ClusterAssignment'] = _CLUSTERASSIGNMENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ClusterAssignment = _reflection.GeneratedProtocolMessageType('ClusterAssignment', (_message.Message,), dict(
  DESCRIPTOR = _CLUSTERASSIGNMENT,
  __module__ = 'flyteidl.admin.cluster_assignment_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.ClusterAssignment)
  ))
_sym_db.RegisterMessage(ClusterAssignment)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/core/compiler.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from flyteidl.core import workflow_pb2 as flyteidl_dot_core_dot_workflow__pb2
from flyteidl.core import tasks_pb2 as flyteidl_dot_core_dot_tasks__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='flyteidl/core/compiler.proto',
  package='flyteidl.core',
  syntax='proto3',
  serialized_options=_b('Z4github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/core'),
  serialized_pb=_b('\n\x1c\x66lyteidl/core/compiler.proto\x12\rflyteidl.core\x1a\x1c\x66lyteidl/core/workflow.proto\x1a\x19\x66lyteidl/core/tasks.proto\"\xd4\x02\n\rConnectionSet\x12@\n\ndownstream\x18\x07 \x03(\x0b\x32,.flyteidl.core.ConnectionSet.DownstreamEntry\x12<\n\x08upstream\x18\x08 \x03(\x0b\x32*.flyteidl.core.ConnectionSet.UpstreamEntry\x1a\x15\n\x06IdList\x12\x0b\n\x03ids\x18\x01 \x03(\t\x1aV\n\x0f\x44ownstreamEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x32\n\x05value\x18\x02 \x01(\x0b\x32#.flyteidl.core.ConnectionSet.IdList:\x02\x38\x01\x1aT\n\rUpstreamEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x32\n\x05value\x18\x02 \x01(\x0b\x32#.flyteidl.core.ConnectionSet.IdList:\x02\x38\x01\"x\n\x10\x43ompiledWorkflow\x12\x31\n\x08template\x18\x01 \x01(\x0b\x32\x1f.flyteidl.core.WorkflowTemplate\x12\x31\n\x0b\x63onnections\x18\x02 \x01(\x0b\x32\x1c.flyteidl.core.ConnectionSet\"=\n\x0c\x43ompiledTask\x12-\n\x08template\x18\x01 \x01(\x0b\x32\x1b.flyteidl.core.TaskTemplate\"\xaf\x01\n\x17\x43ompiledWorkflowClosure\x12\x30\n\x07primary\x18\x01 \x01(\x0b\x32\x1f.flyteidl.core.CompiledWorkflow\x12\x36\n\rsub_workflows\x18\x02 \x03(\x0b\x32\x1f.flyteidl.core.CompiledWorkflow\x12*\n\x05tasks\x18\x03 \x03(\x0b\x32\x1b.flyteidl.core.CompiledTaskB6Z4github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/coreb\x06proto3')
  ,
  dependencies=[flyteidl_dot_core_dot_workflow__pb2.DESCRIPTOR,flyteidl_dot_core_dot_tasks__pb2.DESCRIPTOR,])




_CONNECTIONSET_IDLIST = _descriptor.Descriptor(
  name='IdList',
  full_name='flyteidl.core.ConnectionSet.IdList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ids', full_name='flyteidl.core.ConnectionSet.IdList.ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=250,
  serialized_end=271,
)

_CONNECTIONSET_DOWNSTREAMENTRY = _descriptor.Descriptor(
  name='DownstreamEntry',
  full_name='flyteidl.core.ConnectionSet.DownstreamEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='flyteidl.core.ConnectionSet.DownstreamEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='flyteidl.core.ConnectionSet.DownstreamEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=273,
  serialized_end=359,
)

_CONNECTIONSET_UPSTREAMENTRY = _descriptor.Descriptor(
  name='UpstreamEntry',
  full_name='flyteidl.core.ConnectionSet.UpstreamEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='flyteidl.core.ConnectionSet.UpstreamEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='flyteidl.core.ConnectionSet.UpstreamEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=361,
  serialized_end=445,
)

_CONNECTIONSET = _descriptor.Descriptor(
  name='ConnectionSet',
  full_name='flyteidl.core.ConnectionSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='downstream', full_name='flyteidl.core.ConnectionSet.downstream', index=0,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='upstream', full_name='flyteidl.core.ConnectionSet.upstream', index=1,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CONNECTIONSET_IDLIST, _CONNECTIONSET_DOWNSTREAMENTRY, _CONNECTIONSET_UPSTREAMENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=105,
  serialized_end=445,
)


_COMPILEDWORKFLOW = _descriptor.Descriptor(
  name='CompiledWorkflow',
  full_name='flyteidl.core.CompiledWorkflow',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='template', full_name='flyteidl.core.CompiledWorkflow.template', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='connections', full_name='flyteidl.core.CompiledWorkflow.connections', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=447,
  serialized_end=567,
)


_COMPILEDTASK = _descriptor.Descriptor(
  name='CompiledTask',
  full_name='flyteidl.core.CompiledTask',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='template', full_name='flyteidl.core.CompiledTask.template', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=569,
  serialized_end=630,
)


_COMPILEDWORKFLOWCLOSURE = _descriptor.Descriptor(
  name='CompiledWorkflowClosure',
  full_name='flyteidl.core.CompiledWorkflowClosure',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='primary', full_name='flyteidl.core.CompiledWorkflowClosure.primary', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sub_workflows', full_name='flyteidl.core.CompiledWorkflowClosure.sub_workflows', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tasks', full_name='flyteidl.core.CompiledWorkflowClosure.tasks', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=633,
  serialized_end=808,
)

_CONNECTIONSET_IDLIST.containing_type = _CONNECTIONSET
_CONNECTIONSET_DOWNSTREAMENTRY.fields_by_name['value'].message_type = _CONNECTIONSET_IDLIST
_CONNECTIONSET_DOWNSTREAMENTRY.containing_type = _CONNECTIONSET
_CONNECTIONSET_UPSTREAMENTRY.fields_by_name['value'].message_type = _CONNECTIONSET_IDLIST
_CONNECTIONSET_UPSTREAMENTRY.containing_type = _CONNECTIONSET
_CONNECTIONSET.fields_by_name['downstream'].message_type = _CONNECTIONSET_DOWNSTREAMENTRY
_CONNECTIONSET.fields_by_name['upstream'].message_type = _CONNECTIONSET_UPSTREAMENTRY
_COMPILEDWORKFLOW.fields_by_name['template'].message_type = flyteidl_dot_core_dot_workflow__pb2._WORKFLOWTEMPLATE
_COMPILEDWORKFLOW.fields_by_name['connections'].message_type = _CONNECTIONSET
_COMPILEDTASK.fields_by_name['template'].message_type = flyteidl_dot_core_dot_tasks__pb2._TASKTEMPLATE
_COMPILEDWORKFLOWCLOSURE.fields_by_name['primary'].message_type = _COMPILEDWORKFLOW
_COMPILEDWORKFLOWCLOSURE.fields_by_name['sub_workflows'].message_type = _COMPILEDWORKFLOW
_COMPILEDWORKFLOWCLOSURE.fields_by_name['tasks'].message_type = _COMPILEDTASK
DESCRIPTOR.message_types_by_name['ConnectionSet'] = _CONNECTIONSET
DESCRIPTOR.message_types_by_name['CompiledWorkflow'] = _COMPILEDWORKFLOW
DESCRIPTOR.message_types_by_name['CompiledTask'] = _COMPILEDTASK
DESCRIPTOR.message_types_by_name['CompiledWorkflowClosure'] = _COMPILEDWORKFLOWCLOSURE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ConnectionSet = _reflection.GeneratedProtocolMessageType('ConnectionSet', (_message.Message,), dict(

  IdList = _reflection.GeneratedProtocolMessageType('IdList', (_message.Message,), dict(
    DESCRIPTOR = _CONNECTIONSET_IDLIST,
    __module__ = 'flyteidl.core.compiler_pb2'
    # @@protoc_insertion_point(class_scope:flyteidl.core.ConnectionSet.IdList)
    ))
  ,

  DownstreamEntry = _reflection.GeneratedProtocolMessageType('DownstreamEntry', (_message.Message,), dict(
    DESCRIPTOR = _CONNECTIONSET_DOWNSTREAMENTRY,
    __module__ = 'flyteidl.core.compiler_pb2'
    # @@protoc_insertion_point(class_scope:flyteidl.core.ConnectionSet.DownstreamEntry)
    ))
  ,

  UpstreamEntry = _reflection.GeneratedProtocolMessageType('UpstreamEntry', (_message.Message,), dict(
    DESCRIPTOR = _CONNECTIONSET_UPSTREAMENTRY,
    __module__ = 'flyteidl.core.compiler_pb2'
    # @@protoc_insertion_point(class_scope:flyteidl.core.ConnectionSet.UpstreamEntry)
    ))
  ,
  DESCRIPTOR = _CONNECTIONSET,
  __module__ = 'flyteidl.core.compiler_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.core.ConnectionSet)
  ))
_sym_db.RegisterMessage(ConnectionSet)
_sym_db.RegisterMessage(ConnectionSet.IdList)
_sym_db.RegisterMessage(ConnectionSet.DownstreamEntry)
_sym_db.RegisterMessage(ConnectionSet.UpstreamEntry)

CompiledWorkflow = _reflection.GeneratedProtocolMessageType('CompiledWorkflow', (_message.Message,), dict(
  DESCRIPTOR = _COMPILEDWORKFLOW,
  __module__ = 'flyteidl.core.compiler_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.core.CompiledWorkflow)
  ))
_sym_db.RegisterMessage(CompiledWorkflow)

CompiledTask = _reflection.GeneratedProtocolMessageType('CompiledTask', (_message.Message,), dict(
  DESCRIPTOR = _COMPILEDTASK,
  __module__ = 'flyteidl.core.compiler_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.core.CompiledTask)
  ))
_sym_db.RegisterMessage(CompiledTask)

CompiledWorkflowClosure = _reflection.GeneratedProtocolMessageType('CompiledWorkflowClosure', (_message.Message,), dict(
  DESCRIPTOR = _COMPILEDWORKFLOWCLOSURE,
  __module__ = 'flyteidl.core.compiler_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.core.CompiledWorkflowClosure)
  ))
_sym_db.RegisterMessage(CompiledWorkflowClosure)


DESCRIPTOR._options = None
_CONNECTIONSET_DOWNSTREAMENTRY._options = None
_CONNECTIONSET_UPSTREAMENTRY._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/admin/execution.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from flyteidl.admin import cluster_assignment_pb2 as flyteidl_dot_admin_dot_cluster__assignment__pb2
from flyteidl.admin import common_pb2 as flyteidl_dot_admin_dot_common__pb2
from flyteidl.core import literals_pb2 as flyteidl_dot_core_dot_literals__pb2
from flyteidl.core import execution_pb2 as flyteidl_dot_core_dot_execution__pb2
from flyteidl.core import identifier_pb2 as flyteidl_dot_core_dot_identifier__pb2
from flyteidl.core import security_pb2 as flyteidl_dot_core_dot_security__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='flyteidl/admin/execution.proto',
  package='flyteidl.admin',
  syntax='proto3',
  serialized_options=_b('Z5github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/admin'),
  serialized_pb=_b('\n\x1e\x66lyteidl/admin/execution.proto\x12\x0e\x66lyteidl.admin\x1a\'flyteidl/admin/cluster_assignment.proto\x1a\x1b\x66lyteidl/admin/common.proto\x1a\x1c\x66lyteidl/core/literals.proto\x1a\x1d\x66lyteidl/core/execution.proto\x1a\x1e\x66lyteidl/core/identifier.proto\x1a\x1c\x66lyteidl/core/security.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\x9f\x01\n\x16\x45xecutionCreateRequest\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x0e\n\x06\x64omain\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12+\n\x04spec\x18\x04 \x01(\x0b\x32\x1d.flyteidl.admin.ExecutionSpec\x12)\n\x06inputs\x18\x05 \x01(\x0b\x32\x19.flyteidl.core.LiteralMap\"`\n\x18\x45xecutionRelaunchRequest\x12\x36\n\x02id\x18\x01 \x01(\x0b\x32*.flyteidl.core.WorkflowExecutionIdentifier\x12\x0c\n\x04name\x18\x03 \x01(\t\"\x94\x01\n\x17\x45xecutionRecoverRequest\x12\x36\n\x02id\x18\x01 \x01(\x0b\x32*.flyteidl.core.WorkflowExecutionIdentifier\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x33\n\x08metadata\x18\x03 \x01(\x0b\x32!.flyteidl.admin.ExecutionMetadata\"Q\n\x17\x45xecutionCreateResponse\x12\x36\n\x02id\x18\x01 \x01(\x0b\x32*.flyteidl.core.WorkflowExecutionIdentifier\"U\n\x1bWorkflowExecutionGetRequest\x12\x36\n\x02id\x18\x01 \x01(\x0b\x32*.flyteidl.core.WorkflowExecutionIdentifier\"\xa3\x01\n\tExecution\x12\x36\n\x02id\x18\x01 \x01(\x0b\x32*.flyteidl.core.WorkflowExecutionIdentifier\x12+\n\x04spec\x18\x02 \x01(\x0b\x32\x1d.flyteidl.admin.ExecutionSpec\x12\x31\n\x07\x63losure\x18\x03 \x01(\x0b\x32 .flyteidl.admin.ExecutionClosure\"M\n\rExecutionList\x12-\n\nexecutions\x18\x01 \x03(\x0b\x32\x19.flyteidl.admin.Execution\x12\r\n\x05token\x18\x02 \x01(\t\"X\n\x0eLiteralMapBlob\x12/\n\x06values\x18\x01 \x01(\x0b\x32\x19.flyteidl.core.LiteralMapB\x02\x18\x01H\x00\x12\r\n\x03uri\x18\x02 \x01(\tH\x00\x42\x06\n\x04\x64\x61ta\"1\n\rAbortMetadata\x12\r\n\x05\x63\x61use\x18\x01 \x01(\t\x12\x11\n\tprincipal\x18\x02 \x01(\t\"\xf0\x05\n\x10\x45xecutionClosure\x12\x35\n\x07outputs\x18\x01 \x01(\x0b\x32\x1e.flyteidl.admin.LiteralMapBlobB\x02\x18\x01H\x00\x12.\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x1d.flyteidl.core.ExecutionErrorH\x00\x12\x19\n\x0b\x61\x62ort_cause\x18\n \x01(\tB\x02\x18\x01H\x00\x12\x37\n\x0e\x61\x62ort_metadata\x18\x0c \x01(\x0b\x32\x1d.flyteidl.admin.AbortMetadataH\x00\x12\x34\n\x0boutput_data\x18\r \x01(\x0b\x32\x19.flyteidl.core.LiteralMapB\x02\x18\x01H\x00\x12\x36\n\x0f\x63omputed_inputs\x18\x03 \x01(\x0b\x32\x19.flyteidl.core.LiteralMapB\x02\x18\x01\x12\x35\n\x05phase\x18\x04 \x01(\x0e\x32&.flyteidl.core.WorkflowExecution.Phase\x12.\n\nstarted_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x08\x64uration\x18\x06 \x01(\x0b\x32\x19.google.protobuf.Duration\x12.\n\ncreated_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x33\n\rnotifications\x18\t \x03(\x0b\x32\x1c.flyteidl.admin.Notification\x12.\n\x0bworkflow_id\x18\x0b \x01(\x0b\x32\x19.flyteidl.core.Identifier\x12I\n\x14state_change_details\x18\x0e \x01(\x0b\x32+.flyteidl.admin.ExecutionStateChangeDetailsB\x0f\n\routput_result\"+\n\x0eSystemMetadata\x12\x19\n\x11\x65xecution_cluster\x18\x01 \x01(\t\"\xda\x03\n\x11\x45xecutionMetadata\x12=\n\x04mode\x18\x01 \x01(\x0e\x32/.flyteidl.admin.ExecutionMetadata.ExecutionMode\x12\x11\n\tprincipal\x18\x02 \x01(\t\x12\x0f\n\x07nesting\x18\x03 \x01(\r\x12\x30\n\x0cscheduled_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x45\n\x15parent_node_execution\x18\x05 \x01(\x0b\x32&.flyteidl.core.NodeExecutionIdentifier\x12G\n\x13reference_execution\x18\x10 \x01(\x0b\x32*.flyteidl.core.WorkflowExecutionIdentifier\x12\x37\n\x0fsystem_metadata\x18\x11 \x01(\x0b\x32\x1e.flyteidl.admin.SystemMetadata\"g\n\rExecutionMode\x12\n\n\x06MANUAL\x10\x00\x12\r\n\tSCHEDULED\x10\x01\x12\n\n\x06SYSTEM\x10\x02\x12\x0c\n\x08RELAUNCH\x10\x03\x12\x12\n\x0e\x43HILD_WORKFLOW\x10\x04\x12\r\n\tRECOVERED\x10\x05\"G\n\x10NotificationList\x12\x33\n\rnotifications\x18\x01 \x03(\x0b\x32\x1c.flyteidl.admin.Notification\"\xe7\x05\n\rExecutionSpec\x12.\n\x0blaunch_plan\x18\x01 \x01(\x0b\x32\x19.flyteidl.core.Identifier\x12-\n\x06inputs\x18\x02 \x01(\x0b\x32\x19.flyteidl.core.LiteralMapB\x02\x18\x01\x12\x33\n\x08metadata\x18\x03 \x01(\x0b\x32!.flyteidl.admin.ExecutionMetadata\x12\x39\n\rnotifications\x18\x05 \x01(\x0b\x32 .flyteidl.admin.NotificationListH\x00\x12\x15\n\x0b\x64isable_all\x18\x06 \x01(\x08H\x00\x12&\n\x06labels\x18\x07 \x01(\x0b\x32\x16.flyteidl.admin.Labels\x12\x30\n\x0b\x61nnotations\x18\x08 \x01(\x0b\x32\x1b.flyteidl.admin.Annotations\x12\x38\n\x10security_context\x18\n \x01(\x0b\x32\x1e.flyteidl.core.SecurityContext\x12/\n\tauth_role\x18\x10 \x01(\x0b\x32\x18.flyteidl.admin.AuthRoleB\x02\x18\x01\x12;\n\x12quality_of_service\x18\x11 \x01(\x0b\x32\x1f.flyteidl.core.QualityOfService\x12\x17\n\x0fmax_parallelism\x18\x12 \x01(\x05\x12\x43\n\x16raw_output_data_config\x18\x13 \x01(\x0b\x32#.flyteidl.admin.RawOutputDataConfig\x12=\n\x12\x63luster_assignment\x18\x14 \x01(\x0b\x32!.flyteidl.admin.ClusterAssignment\x12\x31\n\rinterruptible\x18\x15 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\x18\n\x16notification_overridesJ\x04\x08\x04\x10\x05\"b\n\x19\x45xecutionTerminateRequest\x12\x36\n\x02id\x18\x01 \x01(\x0b\x32*.flyteidl.core.WorkflowExecutionIdentifier\x12\r\n\x05\x63\x61use\x18\x02 \x01(\t\"\x1c\n\x1a\x45xecutionTerminateResponse\"Y\n\x1fWorkflowExecutionGetDataRequest\x12\x36\n\x02id\x18\x01 \x01(\x0b\x32*.flyteidl.core.WorkflowExecutionIdentifier\"\xde\x01\n WorkflowExecutionGetDataResponse\x12,\n\x07outputs\x18\x01 \x01(\x0b\x32\x17.flyteidl.admin.UrlBlobB\x02\x18\x01\x12+\n\x06inputs\x18\x02 \x01(\x0b\x32\x17.flyteidl.admin.UrlBlobB\x02\x18\x01\x12.\n\x0b\x66ull_inputs\x18\x03 \x01(\x0b\x32\x19.flyteidl.core.LiteralMap\x12/\n\x0c\x66ull_outputs\x18\x04 \x01(\x0b\x32\x19.flyteidl.core.LiteralMap\"\x7f\n\x16\x45xecutionUpdateRequest\x12\x36\n\x02id\x18\x01 \x01(\x0b\x32*.flyteidl.core.WorkflowExecutionIdentifier\x12-\n\x05state\x18\x02 \x01(\x0e\x32\x1e.flyteidl.admin.ExecutionState\"\x90\x01\n\x1b\x45xecutionStateChangeDetails\x12-\n\x05state\x18\x01 \x01(\x0e\x32\x1e.flyteidl.admin.ExecutionState\x12/\n\x0boccurred_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\tprincipal\x18\x03 \x01(\t\"\x19\n\x17\x45xecutionUpdateResponse*>\n\x0e\x45xecutionState\x12\x14\n\x10\x45XECUTION_ACTIVE\x10\x00\x12\x16\n\x12\x45XECUTION_ARCHIVED\x10\x01\x42\x37Z5github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/adminb\x06proto3')
  ,
  dependencies=[flyteidl_dot_admin_dot_cluster__assignment__pb2.DESCRIPTOR,flyteidl_dot_admin_dot_common__pb2.DESCRIPTOR,flyteidl_dot_core_dot_literals__pb2.DESCRIPTOR,flyteidl_dot_core_dot_execution__pb2.DESCRIPTOR,flyteidl_dot_core_dot_identifier__pb2.DESCRIPTOR,flyteidl_dot_core_dot_security__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,])

_EXECUTIONSTATE = _descriptor.EnumDescriptor(
  name='ExecutionState',
  full_name='flyteidl.admin.ExecutionState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EXECUTION_ACTIVE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXECUTION_ARCHIVED', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4152,
  serialized_end=4214,
)
_sym_db.RegisterEnumDescriptor(_EXECUTIONSTATE)

ExecutionState = enum_type_wrapper.EnumTypeWrapper(_EXECUTIONSTATE)
EXECUTION_ACTIVE = 0
EXECUTION_ARCHIVED = 1


_EXECUTIONMETADATA_EXECUTIONMODE = _descriptor.EnumDescriptor(
  name='ExecutionMode',
  full_name='flyteidl.admin.ExecutionMetadata.ExecutionMode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MANUAL', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SCHEDULED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SYSTEM', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RELAUNCH', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CHILD_WORKFLOW', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RECOVERED', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2479,
  serialized_end=2582,
)
_sym_db.RegisterEnumDescriptor(_EXECUTIONMETADATA_EXECUTIONMODE)


_EXECUTIONCREATEREQUEST = _descriptor.Descriptor(
  name='ExecutionCreateRequest',
  full_name='flyteidl.admin.ExecutionCreateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='project', full_name='flyteidl.admin.ExecutionCreateRequest.project', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='domain', full_name='flyteidl.admin.ExecutionCreateRequest.domain', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='flyteidl.admin.ExecutionCreateRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spec', full_name='flyteidl.admin.ExecutionCreateRequest.spec', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inputs', full_name='flyteidl.admin.ExecutionCreateRequest.inputs', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=341,
  serialized_end=500,
)


_EXECUTIONRELAUNCHREQUEST = _descriptor.Descriptor(
  name='ExecutionRelaunchRequest',
  full_name='flyteidl.admin.ExecutionRelaunchRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='flyteidl.admin.ExecutionRelaunchRequest.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='flyteidl.admin.ExecutionRelaunchRequest.name', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=502,
  serialized_end=598,
)


_EXECUTIONRECOVERREQUEST = _descriptor.Descriptor(
  name='ExecutionRecoverRequest',
  full_name='flyteidl.admin.ExecutionRecoverRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='flyteidl.admin.ExecutionRecoverRequest.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='flyteidl.admin.ExecutionRecoverRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='flyteidl.admin.ExecutionRecoverRequest.metadata', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=601,
  serialized_end=749,
)


_EXECUTIONCREATERESPONSE = _descriptor.Descriptor(
  name='ExecutionCreateResponse',
  full_name='flyteidl.admin.ExecutionCreateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='flyteidl.admin.ExecutionCreateResponse.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=751,
  serialized_end=832,
)


_WORKFLOWEXECUTIONGETREQUEST = _descriptor.Descriptor(
  name='WorkflowExecutionGetRequest',
  full_name='flyteidl.admin.WorkflowExecutionGetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='flyteidl.admin.WorkflowExecutionGetRequest.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=834,
  serialized_end=919,
)


_EXECUTION = _descriptor.Descriptor(
  name='Execution',
  full_name='flyteidl.admin.Execution',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='flyteidl.admin.Execution.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spec', full_name='flyteidl.admin.Execution.spec', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='closure', full_name='flyteidl.admin.Execution.closure', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=922,
  serialized_end=1085,
)


_EXECUTIONLIST = _descriptor.Descriptor(
  name='ExecutionList',
  full_name='flyteidl.admin.ExecutionList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='executions', full_name='flyteidl.admin.ExecutionList.executions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='token', full_name='flyteidl.admin.ExecutionList.token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1087,
  serialized_end=1164,
)


_LITERALMAPBLOB = _descriptor.Descriptor(
  name='LiteralMapBlob',
  full_name='flyteidl.admin.LiteralMapBlob',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='flyteidl.admin.LiteralMapBlob.values', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uri', full_name='flyteidl.admin.LiteralMapBlob.uri', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='flyteidl.admin.LiteralMapBlob.data',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1166,
  serialized_end=1254,
)


_ABORTMETADATA = _descriptor.Descriptor(
  name='AbortMetadata',
  full_name='flyteidl.admin.AbortMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cause', full_name='flyteidl.admin.AbortMetadata.cause', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='principal', full_name='flyteidl.admin.AbortMetadata.principal', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1256,
  serialized_end=1305,
)


_EXECUTIONCLOSURE = _descriptor.Descriptor(
  name='ExecutionClosure',
  full_name='flyteidl.admin.ExecutionClosure',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='outputs', full_name='flyteidl.admin.ExecutionClosure.outputs', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='flyteidl.admin.ExecutionClosure.error', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='abort_cause', full_name='flyteidl.admin.ExecutionClosure.abort_cause', index=2,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='abort_metadata', full_name='flyteidl.admin.ExecutionClosure.abort_metadata', index=3,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='output_data', full_name='flyteidl.admin.ExecutionClosure.output_data', index=4,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='computed_inputs', full_name='flyteidl.admin.ExecutionClosure.computed_inputs', index=5,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='phase', full_name='flyteidl.admin.ExecutionClosure.phase', index=6,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='started_at', full_name='flyteidl.admin.ExecutionClosure.started_at', index=7,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duration', full_name='flyteidl.admin.ExecutionClosure.duration', index=8,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='flyteidl.admin.ExecutionClosure.created_at', index=9,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='flyteidl.admin.ExecutionClosure.updated_at', index=10,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='notifications', full_name='flyteidl.admin.ExecutionClosure.notifications', index=11,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='workflow_id', full_name='flyteidl.admin.ExecutionClosure.workflow_id', index=12,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state_change_details', full_name='flyteidl.admin.ExecutionClosure.state_change_details', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='output_result', full_name='flyteidl.admin.ExecutionClosure.output_result',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1308,
  serialized_end=2060,
)


_SYSTEMMETADATA = _descriptor.Descriptor(
  name='SystemMetadata',
  full_name='flyteidl.admin.SystemMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='execution_cluster', full_name='flyteidl.admin.SystemMetadata.execution_cluster', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2062,
  serialized_end=2105,
)


_EXECUTIONMETADATA = _descriptor.Descriptor(
  name='ExecutionMetadata',
  full_name='flyteidl.admin.ExecutionMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode', full_name='flyteidl.admin.ExecutionMetadata.mode', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='principal', full_name='flyteidl.admin.ExecutionMetadata.principal', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nesting', full_name='flyteidl.admin.ExecutionMetadata.nesting', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scheduled_at', full_name='flyteidl.admin.ExecutionMetadata.scheduled_at', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parent_node_execution', full_name='flyteidl.admin.ExecutionMetadata.parent_node_execution', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reference_execution', full_name='flyteidl.admin.ExecutionMetadata.reference_execution', index=5,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='system_metadata', full_name='flyteidl.admin.ExecutionMetadata.system_metadata', index=6,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _EXECUTIONMETADATA_EXECUTIONMODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2108,
  serialized_end=2582,
)


_NOTIFICATIONLIST = _descriptor.Descriptor(
  name='NotificationList',
  full_name='flyteidl.admin.NotificationList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='notifications', full_name='flyteidl.admin.NotificationList.notifications', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2584,
  serialized_end=2655,
)


_EXECUTIONSPEC = _descriptor.Descriptor(
  name='ExecutionSpec',
  full_name='flyteidl.admin.ExecutionSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='launch_plan', full_name='flyteidl.admin.ExecutionSpec.launch_plan', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inputs', full_name='flyteidl.admin.ExecutionSpec.inputs', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='flyteidl.admin.ExecutionSpec.metadata', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='notifications', full_name='flyteidl.admin.ExecutionSpec.notifications', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='disable_all', full_name='flyteidl.admin.ExecutionSpec.disable_all', index=4,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='labels', full_name='flyteidl.admin.ExecutionSpec.labels', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='annotations', full_name='flyteidl.admin.ExecutionSpec.annotations', index=6,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='security_context', full_name='flyteidl.admin.ExecutionSpec.security_context', index=7,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='auth_role', full_name='flyteidl.admin.ExecutionSpec.auth_role', index=8,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quality_of_service', full_name='flyteidl.admin.ExecutionSpec.quality_of_service', index=9,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_parallelism', full_name='flyteidl.admin.ExecutionSpec.max_parallelism', index=10,
      number=18, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='raw_output_data_config', full_name='flyteidl.admin.ExecutionSpec.raw_output_data_config', index=11,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cluster_assignment', full_name='flyteidl.admin.ExecutionSpec.cluster_assignment', index=12,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='interruptible', full_name='flyteidl.admin.ExecutionSpec.interruptible', index=13,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='notification_overrides', full_name='flyteidl.admin.ExecutionSpec.notification_overrides',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=2658,
  serialized_end=3401,
)


_EXECUTIONTERMINATEREQUEST = _descriptor.Descriptor(
  name='ExecutionTerminateRequest',
  full_name='flyteidl.admin.ExecutionTerminateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='flyteidl.admin.ExecutionTerminateRequest.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cause', full_name='flyteidl.admin.ExecutionTerminateRequest.cause', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3403,
  serialized_end=3501,
)


_EXECUTIONTERMINATERESPONSE = _descriptor.Descriptor(
  name='ExecutionTerminateResponse',
  full_name='flyteidl.admin.ExecutionTerminateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3503,
  serialized_end=3531,
)


_WORKFLOWEXECUTIONGETDATAREQUEST = _descriptor.Descriptor(
  name='WorkflowExecutionGetDataRequest',
  full_name='flyteidl.admin.WorkflowExecutionGetDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='flyteidl.admin.WorkflowExecutionGetDataRequest.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3533,
  serialized_end=3622,
)


_WORKFLOWEXECUTIONGETDATARESPONSE = _descriptor.Descriptor(
  name='WorkflowExecutionGetDataResponse',
  full_name='flyteidl.admin.WorkflowExecutionGetDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='outputs', full_name='flyteidl.admin.WorkflowExecutionGetDataResponse.outputs', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inputs', full_name='flyteidl.admin.WorkflowExecutionGetDataResponse.inputs', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='full_inputs', full_name='flyteidl.admin.WorkflowExecutionGetDataResponse.full_inputs', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='full_outputs', full_name='flyteidl.admin.WorkflowExecutionGetDataResponse.full_outputs', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3625,
  serialized_end=3847,
)


_EXECUTIONUPDATEREQUEST = _descriptor.Descriptor(
  name='ExecutionUpdateRequest',
  full_name='flyteidl.admin.ExecutionUpdateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='flyteidl.admin.ExecutionUpdateRequest.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='flyteidl.admin.ExecutionUpdateRequest.state', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3849,
  serialized_end=3976,
)


_EXECUTIONSTATECHANGEDETAILS = _descriptor.Descriptor(
  name='ExecutionStateChangeDetails',
  full_name='flyteidl.admin.ExecutionStateChangeDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='flyteidl.admin.ExecutionStateChangeDetails.state', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='occurred_at', full_name='flyteidl.admin.ExecutionStateChangeDetails.occurred_at', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='principal', full_name='flyteidl.admin.ExecutionStateChangeDetails.principal', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3979,
  serialized_end=4123,
)


_EXECUTIONUPDATERESPONSE = _descriptor.Descriptor(
  name='ExecutionUpdateResponse',
  full_name='flyteidl.admin.ExecutionUpdateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4125,
  serialized_end=4150,
)

_EXECUTIONCREATEREQUEST.fields_by_name['spec'].message_type = _EXECUTIONSPEC
_EXECUTIONCREATEREQUEST.fields_by_name['inputs'].message_type = flyteidl_dot_core_dot_literals__pb2._LITERALMAP
_EXECUTIONRELAUNCHREQUEST.fields_by_name['id'].message_type = flyteidl_dot_core_dot_identifier__pb2._WORKFLOWEXECUTIONIDENTIFIER
_EXECUTIONRECOVERREQUEST.fields_by_name['id'].message_type = flyteidl_dot_core_dot_identifier__pb2._WORKFLOWEXECUTIONIDENTIFIER
_EXECUTIONRECOVERREQUEST.fields_by_name['metadata'].message_type = _EXECUTIONMETADATA
_EXECUTIONCREATERESPONSE.fields_by_name['id'].message_type = flyteidl_dot_core_dot_identifier__pb2._WORKFLOWEXECUTIONIDENTIFIER
_WORKFLOWEXECUTIONGETREQUEST.fields_by_name['id'].message_type = flyteidl_dot_core_dot_identifier__pb2._WORKFLOWEXECUTIONIDENTIFIER
_EXECUTION.fields_by_name['id'].message_type = flyteidl_dot_core_dot_identifier__pb2._WORKFLOWEXECUTIONIDENTIFIER
_EXECUTION.fields_by_name['spec'].message_type = _EXECUTIONSPEC
_EXECUTION.fields_by_name['closure'].message_type = _EXECUTIONCLOSURE
_EXECUTIONLIST.fields_by_name['executions'].message_type = _EXECUTION
_LITERALMAPBLOB.fields_by_name['values'].message_type = flyteidl_dot_core_dot_literals__pb2._LITERALMAP
_LITERALMAPBLOB.oneofs_by_name['data'].fields.append(
  _LITERALMAPBLOB.fields_by_name['values'])
_LITERALMAPBLOB.fields_by_name['values'].containing_oneof = _LITERALMAPBLOB.oneofs_by_name['data']
_LITERALMAPBLOB.oneofs_by_name['data'].fields.append(
  _LITERALMAPBLOB.fields_by_name['uri'])
_LITERALMAPBLOB.fields_by_name['uri'].containing_oneof = _LITERALMAPBLOB.oneofs_by_name['data']
_EXECUTIONCLOSURE.fields_by_name['outputs'].message_type = _LITERALMAPBLOB
_EXECUTIONCLOSURE.fields_by_name['error'].message_type = flyteidl_dot_core_dot_execution__pb2._EXECUTIONERROR
_EXECUTIONCLOSURE.fields_by_name['abort_metadata'].message_type = _ABORTMETADATA
_EXECUTIONCLOSURE.fields_by_name['output_data'].message_type = flyteidl_dot_core_dot_literals__pb2._LITERALMAP
_EXECUTIONCLOSURE.fields_by_name['computed_inputs'].message_type = flyteidl_dot_core_dot_literals__pb2._LITERALMAP
_EXECUTIONCLOSURE.fields_by_name['phase'].enum_type = flyteidl_dot_core_dot_execution__pb2._WORKFLOWEXECUTION_PHASE
_EXECUTIONCLOSURE.fields_by_name['started_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EXECUTIONCLOSURE.fields_by_name['duration'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_EXECUTIONCLOSURE.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EXECUTIONCLOSURE.fields_by_name['updated_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EXECUTIONCLOSURE.fields_by_name['notifications'].message_type = flyteidl_dot_admin_dot_common__pb2._NOTIFICATION
_EXECUTIONCLOSURE.fields_by_name['workflow_id'].message_type = flyteidl_dot_core_dot_identifier__pb2._IDENTIFIER
_EXECUTIONCLOSURE.fields_by_name['state_change_details'].message_type = _EXECUTIONSTATECHANGEDETAILS
_EXECUTIONCLOSURE.oneofs_by_name['output_result'].fields.append(
  _EXECUTIONCLOSURE.fields_by_name['outputs'])
_EXECUTIONCLOSURE.fields_by_name['outputs'].containing_oneof = _EXECUTIONCLOSURE.oneofs_by_name['output_result']
_EXECUTIONCLOSURE.oneofs_by_name['output_result'].fields.append(
  _EXECUTIONCLOSURE.fields_by_name['error'])
_EXECUTIONCLOSURE.fields_by_name['error'].containing_oneof = _EXECUTIONCLOSURE.oneofs_by_name['output_result']
_EXECUTIONCLOSURE.oneofs_by_name['output_result'].fields.append(
  _EXECUTIONCLOSURE.fields_by_name['abort_cause'])
_EXECUTIONCLOSURE.fields_by_name['abort_cause'].containing_oneof = _EXECUTIONCLOSURE.oneofs_by_name['output_result']
_EXECUTIONCLOSURE.oneofs_by_name['output_result'].fields.append(
  _EXECUTIONCLOSURE.fields_by_name['abort_metadata'])
_EXECUTIONCLOSURE.fields_by_name['abort_metadata'].containing_oneof = _EXECUTIONCLOSURE.oneofs_by_name['output_result']
_EXECUTIONCLOSURE.oneofs_by_name['output_result'].fields.append(
  _EXECUTIONCLOSURE.fields_by_name['output_data'])
_EXECUTIONCLOSURE.fields_by_name['output_data'].containing_oneof = _EXECUTIONCLOSURE.oneofs_by_name['output_result']
_EXECUTIONMETADATA.fields_by_name['mode'].enum_type = _EXECUTIONMETADATA_EXECUTIONMODE
_EXECUTIONMETADATA.fields_by_name['scheduled_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EXECUTIONMETADATA.fields_by_name['parent_node_execution'].message_type = flyteidl_dot_core_dot_identifier__pb2._NODEEXECUTIONIDENTIFIER
_EXECUTIONMETADATA.fields_by_name['reference_execution'].message_type = flyteidl_dot_core_dot_identifier__pb2._WORKFLOWEXECUTIONIDENTIFIER
_EXECUTIONMETADATA.fields_by_name['system_metadata'].message_type = _SYSTEMMETADATA
_EXECUTIONMETADATA_EXECUTIONMODE.containing_type = _EXECUTIONMETADATA
_NOTIFICATIONLIST.fields_by_name['notifications'].message_type = flyteidl_dot_admin_dot_common__pb2._NOTIFICATION
_EXECUTIONSPEC.fields_by_name['launch_plan'].message_type = flyteidl_dot_core_dot_identifier__pb2._IDENTIFIER
_EXECUTIONSPEC.fields_by_name['inputs'].message_type = flyteidl_dot_core_dot_literals__pb2._LITERALMAP
_EXECUTIONSPEC.fields_by_name['metadata'].message_type = _EXECUTIONMETADATA
_EXECUTIONSPEC.fields_by_name['notifications'].message_type = _NOTIFICATIONLIST
_EXECUTIONSPEC.fields_by_name['labels'].message_type = flyteidl_dot_admin_dot_common__pb2._LABELS
_EXECUTIONSPEC.fields_by_name['annotations'].message_type = flyteidl_dot_admin_dot_common__pb2._ANNOTATIONS
_EXECUTIONSPEC.fields_by_name['security_context'].message_type = flyteidl_dot_core_dot_security__pb2._SECURITYCONTEXT
_EXECUTIONSPEC.fields_by_name['auth_role'].message_type = flyteidl_dot_admin_dot_common__pb2._AUTHROLE
_EXECUTIONSPEC.fields_by_name['quality_of_service'].message_type = flyteidl_dot_core_dot_execution__pb2._QUALITYOFSERVICE
_EXECUTIONSPEC.fields_by_name['raw_output_data_config'].message_type = flyteidl_dot_admin_dot_common__pb2._RAWOUTPUTDATACONFIG
_EXECUTIONSPEC.fields_by_name['cluster_assignment'].message_type = flyteidl_dot_admin_dot_cluster__assignment__pb2._CLUSTERASSIGNMENT
_EXECUTIONSPEC.fields_by_name['interruptible'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_EXECUTIONSPEC.oneofs_by_name['notification_overrides'].fields.append(
  _EXECUTIONSPEC.fields_by_name['notifications'])
_EXECUTIONSPEC.fields_by_name['notifications'].containing_oneof = _EXECUTIONSPEC.oneofs_by_name['notification_overrides']
_EXECUTIONSPEC.oneofs_by_name['notification_overrides'].fields.append(
  _EXECUTIONSPEC.fields_by_name['disable_all'])
_EXECUTIONSPEC.fields_by_name['disable_all'].containing_oneof = _EXECUTIONSPEC.oneofs_by_name['notification_overrides']
_EXECUTIONTERMINATEREQUEST.fields_by_name['id'].message_type = flyteidl_dot_core_dot_identifier__pb2._WORKFLOWEXECUTIONIDENTIFIER
_WORKFLOWEXECUTIONGETDATAREQUEST.fields_by_name['id'].message_type = flyteidl_dot_core_dot_identifier__pb2._WORKFLOWEXECUTIONIDENTIFIER
_WORKFLOWEXECUTIONGETDATARESPONSE.fields_by_name['outputs'].message_type = flyteidl_dot_admin_dot_common__pb2._URLBLOB
_WORKFLOWEXECUTIONGETDATARESPONSE.fields_by_name['inputs'].message_type = flyteidl_dot_admin_dot_common__pb2._URLBLOB
_WORKFLOWEXECUTIONGETDATARESPONSE.fields_by_name['full_inputs'].message_type = flyteidl_dot_core_dot_literals__pb2._LITERALMAP
_WORKFLOWEXECUTIONGETDATARESPONSE.fields_by_name['full_outputs'].message_type = flyteidl_dot_core_dot_literals__pb2._LITERALMAP
_EXECUTIONUPDATEREQUEST.fields_by_name['id'].message_type = flyteidl_dot_core_dot_identifier__pb2._WORKFLOWEXECUTIONIDENTIFIER
_EXECUTIONUPDATEREQUEST.fields_by_name['state'].enum_type = _EXECUTIONSTATE
_EXECUTIONSTATECHANGEDETAILS.fields_by_name['state'].enum_type = _EXECUTIONSTATE
_EXECUTIONSTATECHANGEDETAILS.fields_by_name['occurred_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['ExecutionCreateRequest'] = _EXECUTIONCREATEREQUEST
DESCRIPTOR.message_types_by_name['ExecutionRelaunchRequest'] = _EXECUTIONRELAUNCHREQUEST
DESCRIPTOR.message_types_by_name['ExecutionRecoverRequest'] = _EXECUTIONRECOVERREQUEST
DESCRIPTOR.message_types_by_name['ExecutionCreateResponse'] = _EXECUTIONCREATERESPONSE
DESCRIPTOR.message_types_by_name['WorkflowExecutionGetRequest'] = _WORKFLOWEXECUTIONGETREQUEST
DESCRIPTOR.message_types_by_name['Execution'] = _EXECUTION
DESCRIPTOR.message_types_by_name['ExecutionList'] = _EXECUTIONLIST
DESCRIPTOR.message_types_by_name['LiteralMapBlob'] = _LITERALMAPBLOB
DESCRIPTOR.message_types_by_name['AbortMetadata'] = _ABORTMETADATA
DESCRIPTOR.message_types_by_name['ExecutionClosure'] = _EXECUTIONCLOSURE
DESCRIPTOR.message_types_by_name['SystemMetadata'] = _SYSTEMMETADATA
DESCRIPTOR.message_types_by_name['ExecutionMetadata'] = _EXECUTIONMETADATA
DESCRIPTOR.message_types_by_name['NotificationList'] = _NOTIFICATIONLIST
DESCRIPTOR.message_types_by_name['ExecutionSpec'] = _EXECUTIONSPEC
DESCRIPTOR.message_types_by_name['ExecutionTerminateRequest'] = _EXECUTIONTERMINATEREQUEST
DESCRIPTOR.message_types_by_name['ExecutionTerminateResponse'] = _EXECUTIONTERMINATERESPONSE
DESCRIPTOR.message_types_by_name['WorkflowExecutionGetDataRequest'] = _WORKFLOWEXECUTIONGETDATAREQUEST
DESCRIPTOR.message_types_by_name['WorkflowExecutionGetDataResponse'] = _WORKFLOWEXECUTIONGETDATARESPONSE
DESCRIPTOR.message_types_by_name['ExecutionUpdateRequest'] = _EXECUTIONUPDATEREQUEST
DESCRIPTOR.message_types_by_name['ExecutionStateChangeDetails'] = _EXECUTIONSTATECHANGEDETAILS
DESCRIPTOR.message_types_by_name['ExecutionUpdateResponse'] = _EXECUTIONUPDATERESPONSE
DESCRIPTOR.enum_types_by_name['ExecutionState'] = _EXECUTIONSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ExecutionCreateRequest = _reflection.GeneratedProtocolMessageType('ExecutionCreateRequest', (_message.Message,), dict(
  DESCRIPTOR = _EXECUTIONCREATEREQUEST,
  __module__ = 'flyteidl.admin.execution_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.ExecutionCreateRequest)
  ))
_sym_db.RegisterMessage(ExecutionCreateRequest)

ExecutionRelaunchRequest = _reflection.GeneratedProtocolMessageType('ExecutionRelaunchRequest', (_message.Message,), dict(
  DESCRIPTOR = _EXECUTIONRELAUNCHREQUEST,
  __module__ = 'flyteidl.admin.execution_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.ExecutionRelaunchRequest)
  ))
_sym_db.RegisterMessage(ExecutionRelaunchRequest)

ExecutionRecoverRequest = _reflection.GeneratedProtocolMessageType('ExecutionRecoverRequest', (_message.Message,), dict(
  DESCRIPTOR = _EXECUTIONRECOVERREQUEST,
  __module__ = 'flyteidl.admin.execution_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.ExecutionRecoverRequest)
  ))
_sym_db.RegisterMessage(ExecutionRecoverRequest)

ExecutionCreateResponse = _reflection.GeneratedProtocolMessageType('ExecutionCreateResponse', (_message.Message,), dict(
  DESCRIPTOR = _EXECUTIONCREATERESPONSE,
  __module__ = 'flyteidl.admin.execution_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.ExecutionCreateResponse)
  ))
_sym_db.RegisterMessage(ExecutionCreateResponse)

WorkflowExecutionGetRequest = _reflection.GeneratedProtocolMessageType('WorkflowExecutionGetRequest', (_message.Message,), dict(
  DESCRIPTOR = _WORKFLOWEXECUTIONGETREQUEST,
  __module__ = 'flyteidl.admin.execution_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.WorkflowExecutionGetRequest)
  ))
_sym_db.RegisterMessage(WorkflowExecutionGetRequest)

Execution = _reflection.GeneratedProtocolMessageType('Execution', (_message.Message,), dict(
  DESCRIPTOR = _EXECUTION,
  __module__ = 'flyteidl.admin.execution_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.Execution)
  ))
_sym_db.RegisterMessage(Execution)

ExecutionList = _reflection.GeneratedProtocolMessageType('ExecutionList', (_message.Message,), dict(
  DESCRIPTOR = _EXECUTIONLIST,
  __module__ = 'flyteidl.admin.execution_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.ExecutionList)
  ))
_sym_db.RegisterMessage(ExecutionList)

LiteralMapBlob = _reflection.GeneratedProtocolMessageType('LiteralMapBlob', (_message.Message,), dict(
  DESCRIPTOR = _LITERALMAPBLOB,
  __module__ = 'flyteidl.admin.execution_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.LiteralMapBlob)
  ))
_sym_db.RegisterMessage(LiteralMapBlob)

AbortMetadata = _reflection.GeneratedProtocolMessageType('AbortMetadata', (_message.Message,), dict(
  DESCRIPTOR = _ABORTMETADATA,
  __module__ = 'flyteidl.admin.execution_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.AbortMetadata)
  ))
_sym_db.RegisterMessage(AbortMetadata)

ExecutionClosure = _reflection.GeneratedProtocolMessageType('ExecutionClosure', (_message.Message,), dict(
  DESCRIPTOR = _EXECUTIONCLOSURE,
  __module__ = 'flyteidl.admin.execution_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.ExecutionClosure)
  ))
_sym_db.RegisterMessage(ExecutionClosure)

SystemMetadata = _reflection.GeneratedProtocolMessageType('SystemMetadata', (_message.Message,), dict(
  DESCRIPTOR = _SYSTEMMETADATA,
  __module__ = 'flyteidl.admin.execution_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.SystemMetadata)
  ))
_sym_db.RegisterMessage(SystemMetadata)

ExecutionMetadata = _reflection.GeneratedProtocolMessageType('ExecutionMetadata', (_message.Message,), dict(
  DESCRIPTOR = _EXECUTIONMETADATA,
  __module__ = 'flyteidl.admin.execution_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.ExecutionMetadata)
  ))
_sym_db.RegisterMessage(ExecutionMetadata)

NotificationList = _reflection.GeneratedProtocolMessageType('NotificationList', (_message.Message,), dict(
  DESCRIPTOR = _NOTIFICATIONLIST,
  __module__ = 'flyteidl.admin.execution_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.NotificationList)
  ))
_sym_db.RegisterMessage(NotificationList)

ExecutionSpec = _reflection.GeneratedProtocolMessageType('ExecutionSpec', (_message.Message,), dict(
  DESCRIPTOR = _EXECUTIONSPEC,
  __module__ = 'flyteidl.admin.execution_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.ExecutionSpec)
  ))
_sym_db.RegisterMessage(ExecutionSpec)

ExecutionTerminateRequest = _reflection.GeneratedProtocolMessageType('ExecutionTerminateRequest', (_message.Message,), dict(
  DESCRIPTOR = _EXECUTIONTERMINATEREQUEST,
  __module__ = 'flyteidl.admin.execution_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.ExecutionTerminateRequest)
  ))
_sym_db.RegisterMessage(ExecutionTerminateRequest)

ExecutionTerminateResponse = _reflection.GeneratedProtocolMessageType('ExecutionTerminateResponse', (_message.Message,), dict(
  DESCRIPTOR = _EXECUTIONTERMINATERESPONSE,
  __module__ = 'flyteidl.admin.execution_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.ExecutionTerminateResponse)
  ))
_sym_db.RegisterMessage(ExecutionTerminateResponse)

WorkflowExecutionGetDataRequest = _reflection.GeneratedProtocolMessageType('WorkflowExecutionGetDataRequest', (_message.Message,), dict(
  DESCRIPTOR = _WORKFLOWEXECUTIONGETDATAREQUEST,
  __module__ = 'flyteidl.admin.execution_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.WorkflowExecutionGetDataRequest)
  ))
_sym_db.RegisterMessage(WorkflowExecutionGetDataRequest)

WorkflowExecutionGetDataResponse = _reflection.GeneratedProtocolMessageType('WorkflowExecutionGetDataResponse', (_message.Message,), dict(
  DESCRIPTOR = _WORKFLOWEXECUTIONGETDATARESPONSE,
  __module__ = 'flyteidl.admin.execution_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.WorkflowExecutionGetDataResponse)
  ))
_sym_db.RegisterMessage(WorkflowExecutionGetDataResponse)

ExecutionUpdateRequest = _reflection.GeneratedProtocolMessageType('ExecutionUpdateRequest', (_message.Message,), dict(
  DESCRIPTOR = _EXECUTIONUPDATEREQUEST,
  __module__ = 'flyteidl.admin.execution_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.ExecutionUpdateRequest)
  ))
_sym_db.RegisterMessage(ExecutionUpdateRequest)

ExecutionStateChangeDetails = _reflection.GeneratedProtocolMessageType('ExecutionStateChangeDetails', (_message.Message,), dict(
  DESCRIPTOR = _EXECUTIONSTATECHANGEDETAILS,
  __module__ = 'flyteidl.admin.execution_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.ExecutionStateChangeDetails)
  ))
_sym_db.RegisterMessage(ExecutionStateChangeDetails)

ExecutionUpdateResponse = _reflection.GeneratedProtocolMessageType('ExecutionUpdateResponse', (_message.Message,), dict(
  DESCRIPTOR = _EXECUTIONUPDATERESPONSE,
  __module__ = 'flyteidl.admin.execution_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.ExecutionUpdateResponse)
  ))
_sym_db.RegisterMessage(ExecutionUpdateResponse)


DESCRIPTOR._options = None
_LITERALMAPBLOB.fields_by_name['values']._options = None
_EXECUTIONCLOSURE.fields_by_name['outputs']._options = None
_EXECUTIONCLOSURE.fields_by_name['abort_cause']._options = None
_EXECUTIONCLOSURE.fields_by_name['output_data']._options = None
_EXECUTIONCLOSURE.fields_by_name['computed_inputs']._options = None
_EXECUTIONSPEC.fields_by_name['inputs']._options = None
_EXECUTIONSPEC.fields_by_name['auth_role']._options = None
_WORKFLOWEXECUTIONGETDATARESPONSE.fields_by_name['outputs']._options = None
_WORKFLOWEXECUTIONGETDATARESPONSE.fields_by_name['inputs']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/plugins/presto.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='flyteidl/plugins/presto.proto',
  package='flyteidl.plugins',
  syntax='proto3',
  serialized_options=_b('Z7github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/plugins'),
  serialized_pb=_b('\n\x1d\x66lyteidl/plugins/presto.proto\x12\x10\x66lyteidl.plugins\"X\n\x0bPrestoQuery\x12\x15\n\rrouting_group\x18\x01 \x01(\t\x12\x0f\n\x07\x63\x61talog\x18\x02 \x01(\t\x12\x0e\n\x06schema\x18\x03 \x01(\t\x12\x11\n\tstatement\x18\x04 \x01(\tB9Z7github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/pluginsb\x06proto3')
)




_PRESTOQUERY = _descriptor.Descriptor(
  name='PrestoQuery',
  full_name='flyteidl.plugins.PrestoQuery',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='routing_group', full_name='flyteidl.plugins.PrestoQuery.routing_group', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='catalog', full_name='flyteidl.plugins.PrestoQuery.catalog', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='schema', full_name='flyteidl.plugins.PrestoQuery.schema', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='statement', full_name='flyteidl.plugins.PrestoQuery.statement', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=51,
  serialized_end=139,
)

DESCRIPTOR.message_types_by_name['PrestoQuery'] = _PRESTOQUERY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PrestoQuery = _reflection.GeneratedProtocolMessageType('PrestoQuery', (_message.Message,), dict(
  DESCRIPTOR = _PRESTOQUERY,
  __module__ = 'flyteidl.plugins.presto_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.plugins.PrestoQuery)
  ))
_sym_db.RegisterMessage(PrestoQuery)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: flyteidl/admin/project_attributes.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from flyteidl.admin import matchable_resource_pb2 as flyteidl_dot_admin_dot_matchable__resource__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='flyteidl/admin/project_attributes.proto',
  package='flyteidl.admin',
  syntax='proto3',
  serialized_options=_b('Z5github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/admin'),
  serialized_pb=_b('\n\'flyteidl/admin/project_attributes.proto\x12\x0e\x66lyteidl.admin\x1a\'flyteidl/admin/matchable_resource.proto\"e\n\x11ProjectAttributes\x12\x0f\n\x07project\x18\x01 \x01(\t\x12?\n\x13matching_attributes\x18\x02 \x01(\x0b\x32\".flyteidl.admin.MatchingAttributes\"W\n\x1eProjectAttributesUpdateRequest\x12\x35\n\nattributes\x18\x01 \x01(\x0b\x32!.flyteidl.admin.ProjectAttributes\"!\n\x1fProjectAttributesUpdateResponse\"h\n\x1bProjectAttributesGetRequest\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x38\n\rresource_type\x18\x02 \x01(\x0e\x32!.flyteidl.admin.MatchableResource\"U\n\x1cProjectAttributesGetResponse\x12\x35\n\nattributes\x18\x01 \x01(\x0b\x32!.flyteidl.admin.ProjectAttributes\"k\n\x1eProjectAttributesDeleteRequest\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x38\n\rresource_type\x18\x02 \x01(\x0e\x32!.flyteidl.admin.MatchableResource\"!\n\x1fProjectAttributesDeleteResponseB7Z5github.com/flyteorg/flyteidl/gen/pb-go/flyteidl/adminb\x06proto3')
  ,
  dependencies=[flyteidl_dot_admin_dot_matchable__resource__pb2.DESCRIPTOR,])




_PROJECTATTRIBUTES = _descriptor.Descriptor(
  name='ProjectAttributes',
  full_name='flyteidl.admin.ProjectAttributes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='project', full_name='flyteidl.admin.ProjectAttributes.project', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='matching_attributes', full_name='flyteidl.admin.ProjectAttributes.matching_attributes', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=100,
  serialized_end=201,
)


_PROJECTATTRIBUTESUPDATEREQUEST = _descriptor.Descriptor(
  name='ProjectAttributesUpdateRequest',
  full_name='flyteidl.admin.ProjectAttributesUpdateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='attributes', full_name='flyteidl.admin.ProjectAttributesUpdateRequest.attributes', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=203,
  serialized_end=290,
)


_PROJECTATTRIBUTESUPDATERESPONSE = _descriptor.Descriptor(
  name='ProjectAttributesUpdateResponse',
  full_name='flyteidl.admin.ProjectAttributesUpdateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=292,
  serialized_end=325,
)


_PROJECTATTRIBUTESGETREQUEST = _descriptor.Descriptor(
  name='ProjectAttributesGetRequest',
  full_name='flyteidl.admin.ProjectAttributesGetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='project', full_name='flyteidl.admin.ProjectAttributesGetRequest.project', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resource_type', full_name='flyteidl.admin.ProjectAttributesGetRequest.resource_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=327,
  serialized_end=431,
)


_PROJECTATTRIBUTESGETRESPONSE = _descriptor.Descriptor(
  name='ProjectAttributesGetResponse',
  full_name='flyteidl.admin.ProjectAttributesGetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='attributes', full_name='flyteidl.admin.ProjectAttributesGetResponse.attributes', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=433,
  serialized_end=518,
)


_PROJECTATTRIBUTESDELETEREQUEST = _descriptor.Descriptor(
  name='ProjectAttributesDeleteRequest',
  full_name='flyteidl.admin.ProjectAttributesDeleteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='project', full_name='flyteidl.admin.ProjectAttributesDeleteRequest.project', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='resource_type', full_name='flyteidl.admin.ProjectAttributesDeleteRequest.resource_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=520,
  serialized_end=627,
)


_PROJECTATTRIBUTESDELETERESPONSE = _descriptor.Descriptor(
  name='ProjectAttributesDeleteResponse',
  full_name='flyteidl.admin.ProjectAttributesDeleteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=629,
  serialized_end=662,
)

_PROJECTATTRIBUTES.fields_by_name['matching_attributes'].message_type = flyteidl_dot_admin_dot_matchable__resource__pb2._MATCHINGATTRIBUTES
_PROJECTATTRIBUTESUPDATEREQUEST.fields_by_name['attributes'].message_type = _PROJECTATTRIBUTES
_PROJECTATTRIBUTESGETREQUEST.fields_by_name['resource_type'].enum_type = flyteidl_dot_admin_dot_matchable__resource__pb2._MATCHABLERESOURCE
_PROJECTATTRIBUTESGETRESPONSE.fields_by_name['attributes'].message_type = _PROJECTATTRIBUTES
_PROJECTATTRIBUTESDELETEREQUEST.fields_by_name['resource_type'].enum_type = flyteidl_dot_admin_dot_matchable__resource__pb2._MATCHABLERESOURCE
DESCRIPTOR.message_types_by_name['ProjectAttributes'] = _PROJECTATTRIBUTES
DESCRIPTOR.message_types_by_name['ProjectAttributesUpdateRequest'] = _PROJECTATTRIBUTESUPDATEREQUEST
DESCRIPTOR.message_types_by_name['ProjectAttributesUpdateResponse'] = _PROJECTATTRIBUTESUPDATERESPONSE
DESCRIPTOR.message_types_by_name['ProjectAttributesGetRequest'] = _PROJECTATTRIBUTESGETREQUEST
DESCRIPTOR.message_types_by_name['ProjectAttributesGetResponse'] = _PROJECTATTRIBUTESGETRESPONSE
DESCRIPTOR.message_types_by_name['ProjectAttributesDeleteRequest'] = _PROJECTATTRIBUTESDELETEREQUEST
DESCRIPTOR.message_types_by_name['ProjectAttributesDeleteResponse'] = _PROJECTATTRIBUTESDELETERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ProjectAttributes = _reflection.GeneratedProtocolMessageType('ProjectAttributes', (_message.Message,), dict(
  DESCRIPTOR = _PROJECTATTRIBUTES,
  __module__ = 'flyteidl.admin.project_attributes_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.ProjectAttributes)
  ))
_sym_db.RegisterMessage(ProjectAttributes)

ProjectAttributesUpdateRequest = _reflection.GeneratedProtocolMessageType('ProjectAttributesUpdateRequest', (_message.Message,), dict(
  DESCRIPTOR = _PROJECTATTRIBUTESUPDATEREQUEST,
  __module__ = 'flyteidl.admin.project_attributes_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.ProjectAttributesUpdateRequest)
  ))
_sym_db.RegisterMessage(ProjectAttributesUpdateRequest)

ProjectAttributesUpdateResponse = _reflection.GeneratedProtocolMessageType('ProjectAttributesUpdateResponse', (_message.Message,), dict(
  DESCRIPTOR = _PROJECTATTRIBUTESUPDATERESPONSE,
  __module__ = 'flyteidl.admin.project_attributes_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.ProjectAttributesUpdateResponse)
  ))
_sym_db.RegisterMessage(ProjectAttributesUpdateResponse)

ProjectAttributesGetRequest = _reflection.GeneratedProtocolMessageType('ProjectAttributesGetRequest', (_message.Message,), dict(
  DESCRIPTOR = _PROJECTATTRIBUTESGETREQUEST,
  __module__ = 'flyteidl.admin.project_attributes_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.ProjectAttributesGetRequest)
  ))
_sym_db.RegisterMessage(ProjectAttributesGetRequest)

ProjectAttributesGetResponse = _reflection.GeneratedProtocolMessageType('ProjectAttributesGetResponse', (_message.Message,), dict(
  DESCRIPTOR = _PROJECTATTRIBUTESGETRESPONSE,
  __module__ = 'flyteidl.admin.project_attributes_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.ProjectAttributesGetResponse)
  ))
_sym_db.RegisterMessage(ProjectAttributesGetResponse)

ProjectAttributesDeleteRequest = _reflection.GeneratedProtocolMessageType('ProjectAttributesDeleteRequest', (_message.Message,), dict(
  DESCRIPTOR = _PROJECTATTRIBUTESDELETEREQUEST,
  __module__ = 'flyteidl.admin.project_attributes_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.ProjectAttributesDeleteRequest)
  ))
_sym_db.RegisterMessage(ProjectAttributesDeleteRequest)

ProjectAttributesDeleteResponse = _reflection.GeneratedProtocolMessageType('ProjectAttributesDeleteResponse', (_message.Message,), dict(
  DESCRIPTOR = _PROJECTATTRIBUTESDELETERESPONSE,
  __module__ = 'flyteidl.admin.project_attributes_pb2'
  # @@protoc_insertion_point(class_scope:flyteidl.admin.ProjectAttributesDeleteResponse)
  ))
_sym_db.RegisterMessage(ProjectAttributesDeleteResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
